@@ -1,9 +1,9 @@
 from .PreRunEventData import PreRunEventData
 from .RunEventData import RunEventData
-from .TrainingEvaluationEventData import TrainingEvaluationEventData
+from .TrainingEvaluationEventData import TrainingEvalEventData
 
 __all__ = [
     PreRunEventData,
     RunEventData,
-    TrainingEvaluationEventData
+    TrainingEvalEventData
 ]
